* ~~Add KPLS option~~
* ~~Add initial doe specification~~
* ~~Add warm start~~
* ~~Add save doe result in file~~
* ~~Allow to choose clustering number~~
* ~~Add save/load trained GP models~~
* ~~Add qEI usage~~
* ~~Test on SEGOMOE test cases~~
* Add Egor hot start (save doe periodically and restart from it)
* Add Egor periodic reclustering
* Add benchmarks
* Add derivative of reduced likelihood
* Add derivatives of GP models
* Add some parallel computations where relevant 
* Add some options validation
* Add KPLS number of component determination
* Add documentation
* Test, test, test